==> jc-1.4.0.tar.gz: soot/jimple/LocalStmtPair.h <==
// public class soot.jimple.LocalStmtPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f3eb1a40979051d7 soot_jimple_LocalStmtPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_LocalStmtPair_H_
#define _JC_soot_jimple_LocalStmtPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Local$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_LocalStmtPair$sub_refs	_jc_soot_jimple_LocalStmtPair$sub_refs;
typedef struct _jc_soot_jimple_LocalStmtPair$sub_nonrefs	_jc_soot_jimple_LocalStmtPair$sub_nonrefs;
typedef struct _jc_soot_jimple_LocalStmtPair$refs	_jc_soot_jimple_LocalStmtPair$refs;
typedef struct _jc_soot_jimple_LocalStmtPair$nonrefs	_jc_soot_jimple_LocalStmtPair$nonrefs;
typedef struct _jc_soot_jimple_LocalStmtPair$object	_jc_soot_jimple_LocalStmtPair$object;

typedef const struct _jc_soot_jimple_LocalStmtPair$vmethods	_jc_soot_jimple_LocalStmtPair$vmethods;
typedef const struct _jc_soot_jimple_LocalStmtPair$vtable	_jc_soot_jimple_LocalStmtPair$vtable;
typedef const struct _jc_soot_jimple_LocalStmtPair$vtype	_jc_soot_jimple_LocalStmtPair$vtype;

// Constructors
extern void _jc_soot_jimple_LocalStmtPair$method$_init$3ba2e5e0c0971fb6(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_LocalStmtPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_LocalStmtPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_LocalStmtPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_LocalStmtPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_LocalStmtPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *);
};

// Vtable
struct _jc_soot_jimple_LocalStmtPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_LocalStmtPair$vmethods	soot_jimple_LocalStmtPair;
};

// Vtype
struct _jc_soot_jimple_LocalStmtPair$vtype {
	_jc_type			type;
	_jc_soot_jimple_LocalStmtPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_LocalStmtPair$sub_refs {
	struct _jc_object	*local;
	struct _jc_object	*stmt;
};

// Reference instance fields (object)
struct _jc_soot_jimple_LocalStmtPair$refs {
    _jc_soot_jimple_LocalStmtPair$sub_refs	soot_jimple_LocalStmtPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_LocalStmtPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_LocalStmtPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_LocalStmtPair$sub_nonrefs	soot_jimple_LocalStmtPair;
};

// Object instance structure
struct _jc_soot_jimple_LocalStmtPair$object {
	_jc_soot_jimple_LocalStmtPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_LocalStmtPair$vtype	*vtype;
	_jc_soot_jimple_LocalStmtPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_LocalStmtPair$vtype _jc_soot_jimple_LocalStmtPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_LocalStmtPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_LocalStmtPair$class_object;

#endif	/* _JC_soot_jimple_LocalStmtPair_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/LocalStmtPair.h <==
// public class soot.jimple.LocalStmtPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f3eb1a40979051d7 soot_jimple_LocalStmtPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_LocalStmtPair_H_
#define _JC_soot_jimple_LocalStmtPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Local$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_LocalStmtPair$sub_refs	_jc_soot_jimple_LocalStmtPair$sub_refs;
typedef struct _jc_soot_jimple_LocalStmtPair$sub_nonrefs	_jc_soot_jimple_LocalStmtPair$sub_nonrefs;
typedef struct _jc_soot_jimple_LocalStmtPair$refs	_jc_soot_jimple_LocalStmtPair$refs;
typedef struct _jc_soot_jimple_LocalStmtPair$nonrefs	_jc_soot_jimple_LocalStmtPair$nonrefs;
typedef struct _jc_soot_jimple_LocalStmtPair$object	_jc_soot_jimple_LocalStmtPair$object;

typedef const struct _jc_soot_jimple_LocalStmtPair$vmethods	_jc_soot_jimple_LocalStmtPair$vmethods;
typedef const struct _jc_soot_jimple_LocalStmtPair$vtable	_jc_soot_jimple_LocalStmtPair$vtable;
typedef const struct _jc_soot_jimple_LocalStmtPair$vtype	_jc_soot_jimple_LocalStmtPair$vtype;

// Constructors
extern void _jc_soot_jimple_LocalStmtPair$method$_init$3ba2e5e0c0971fb6(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_LocalStmtPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_LocalStmtPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_LocalStmtPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_LocalStmtPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_jimple_LocalStmtPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_LocalStmtPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_LocalStmtPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_LocalStmtPair$vmethods	soot_jimple_LocalStmtPair;
};

// Vtype
struct _jc_soot_jimple_LocalStmtPair$vtype {
	_jc_type			type;
	_jc_soot_jimple_LocalStmtPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_LocalStmtPair$sub_refs {
	struct _jc_object	*local;
	struct _jc_object	*stmt;
};

// Reference instance fields (object)
struct _jc_soot_jimple_LocalStmtPair$refs {
    _jc_soot_jimple_LocalStmtPair$sub_refs	soot_jimple_LocalStmtPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_LocalStmtPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_LocalStmtPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_LocalStmtPair$sub_nonrefs	soot_jimple_LocalStmtPair;
};

// Object instance structure
struct _jc_soot_jimple_LocalStmtPair$object {
	_jc_soot_jimple_LocalStmtPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_LocalStmtPair$vtype	*vtype;
	_jc_soot_jimple_LocalStmtPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_LocalStmtPair$vtype _jc_soot_jimple_LocalStmtPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_LocalStmtPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_LocalStmtPair$class_object;

#endif	/* _JC_soot_jimple_LocalStmtPair_H_ */
